@@ -1,9 +1,9 @@
 
-host = '192.168.84.117'
-port = '30006'
-user = 'root'
-password = 'eisoo.com'
-database = ''
+host = ''
+port = ''
+user = ''
+password = ''
+database = 'AnyRobot'
 
 header = {
     'Accept': 'application/json, text/plain, */*',
